@@ -9,7 +9,7 @@ while ($_ = shift) {
 	/^-c$/ && ($CONFIGFILE = shift, next);
 	&die("undefined commandline argument $_");
 }
-
+	
 	&emlOpenFile($CONFIGFILE);
 	%CONFIG = &emlRead;
 
@@ -21,6 +21,10 @@ while ($_ = shift) {
 	$outfnam = &generateFileName;
 	&creat($outfnam);
 	&emlWrite($outfnam, %HEADER);
+	print $outfnam "\n";
+	while (<STDIN>) {
+		print $outfnam $_;
+	}
 	
 	&okay($outfnam);
 	&exit;
